==> jc-1.4.0.tar.gz: java/lang/Compiler.h <==
// public final class java.lang.Compiler

// class file dependencies
// @dep_class 7a974dba132db4a4 java_lang_Compiler
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_Compiler_H_
#define _JC_java_lang_Compiler_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_Compiler$sub_refs	_jc_java_lang_Compiler$sub_refs;
typedef struct _jc_java_lang_Compiler$sub_nonrefs	_jc_java_lang_Compiler$sub_nonrefs;
typedef struct _jc_java_lang_Compiler$refs	_jc_java_lang_Compiler$refs;
typedef struct _jc_java_lang_Compiler$nonrefs	_jc_java_lang_Compiler$nonrefs;
typedef struct _jc_java_lang_Compiler$object	_jc_java_lang_Compiler$object;

typedef const struct _jc_java_lang_Compiler$vmethods	_jc_java_lang_Compiler$vmethods;
typedef const struct _jc_java_lang_Compiler$vtable	_jc_java_lang_Compiler$vtable;
typedef const struct _jc_java_lang_Compiler$vtype	_jc_java_lang_Compiler$vtype;

// Constructors
extern void _jc_java_lang_Compiler$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_Compiler$object *);

// Static methods
extern struct _jc_java_lang_Object$object *_jc_java_lang_Compiler$method$command$9c4610a0259285ef(_jc_env *, struct _jc_java_lang_Object$object *);
extern jboolean _jc_java_lang_Compiler$method$compileClass$258fd65025401c03(_jc_env *, struct _jc_java_lang_Class$object *);
extern jboolean _jc_java_lang_Compiler$method$compileClasses$f9c43047d6e51ee8(_jc_env *, struct _jc_java_lang_String$object *);
extern void _jc_java_lang_Compiler$method$disable$76bb9c74f42e72e3(_jc_env *);
extern void _jc_java_lang_Compiler$method$enable$d5c88e4ee7026bca(_jc_env *);

// Virtual methods structure
struct _jc_java_lang_Compiler$vmethods {
};

// Vtable
struct _jc_java_lang_Compiler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Compiler$vmethods	java_lang_Compiler;
};

// Vtype
struct _jc_java_lang_Compiler$vtype {
	_jc_type			type;
	_jc_java_lang_Compiler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_Compiler$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_Compiler$refs {
    _jc_java_lang_Compiler$sub_refs	java_lang_Compiler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_Compiler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_Compiler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Compiler$sub_nonrefs	java_lang_Compiler;
};

// Object instance structure
struct _jc_java_lang_Compiler$object {
	_jc_java_lang_Compiler$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_Compiler$vtype	*vtype;
	_jc_java_lang_Compiler$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_Compiler$vtype _jc_java_lang_Compiler$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_Compiler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_Compiler$class_object;

#endif	/* _JC_java_lang_Compiler_H_ */

==> jc-1.4.6.tar.gz: java/lang/Compiler.h <==
// public final class java.lang.Compiler

// class file dependencies
// @dep_class 7a974dba132db4a4 java_lang_Compiler
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_Compiler_H_
#define _JC_java_lang_Compiler_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_Compiler$sub_refs	_jc_java_lang_Compiler$sub_refs;
typedef struct _jc_java_lang_Compiler$sub_nonrefs	_jc_java_lang_Compiler$sub_nonrefs;
typedef struct _jc_java_lang_Compiler$refs	_jc_java_lang_Compiler$refs;
typedef struct _jc_java_lang_Compiler$nonrefs	_jc_java_lang_Compiler$nonrefs;
typedef struct _jc_java_lang_Compiler$object	_jc_java_lang_Compiler$object;

typedef const struct _jc_java_lang_Compiler$vmethods	_jc_java_lang_Compiler$vmethods;
typedef const struct _jc_java_lang_Compiler$vtable	_jc_java_lang_Compiler$vtable;
typedef const struct _jc_java_lang_Compiler$vtype	_jc_java_lang_Compiler$vtype;

// Constructors
extern void _jc_java_lang_Compiler$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_Compiler$object *) _JC_JCNI_ATTR;

// Static methods
extern struct _jc_java_lang_Object$object *_jc_java_lang_Compiler$method$command$9c4610a0259285ef(_jc_env *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_lang_Compiler$method$compileClass$258fd65025401c03(_jc_env *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_lang_Compiler$method$compileClasses$f9c43047d6e51ee8(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_Compiler$method$disable$76bb9c74f42e72e3(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_java_lang_Compiler$method$enable$d5c88e4ee7026bca(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_Compiler$vmethods {
};

// Vtable
struct _jc_java_lang_Compiler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Compiler$vmethods	java_lang_Compiler;
};

// Vtype
struct _jc_java_lang_Compiler$vtype {
	_jc_type			type;
	_jc_java_lang_Compiler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_Compiler$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_Compiler$refs {
    _jc_java_lang_Compiler$sub_refs	java_lang_Compiler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_Compiler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_Compiler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Compiler$sub_nonrefs	java_lang_Compiler;
};

// Object instance structure
struct _jc_java_lang_Compiler$object {
	_jc_java_lang_Compiler$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_Compiler$vtype	*vtype;
	_jc_java_lang_Compiler$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_Compiler$vtype _jc_java_lang_Compiler$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_Compiler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_Compiler$class_object;

#endif	/* _JC_java_lang_Compiler_H_ */
